badRequest constant
int
const badRequest
The server could not read a message, or read one it does not expect.
Implementation
static const int badRequest = 4400;
The server could not read a message, or read one it does not expect.
static const int badRequest = 4400;