internalServerError constant
int
const internalServerError
The server broke on a message it had already accepted as well formed.
Implementation
static const int internalServerError = 4500;
The server broke on a message it had already accepted as well formed.
static const int internalServerError = 4500;