error constant
String
const error
Ends an operation that could not be executed, carrying the errors.
Implementation
static const String error = 'error';
Ends an operation that could not be executed, carrying the errors.
static const String error = 'error';