subscribe constant
String
const subscribe
Starts an operation, under an id the connection has not used yet.
Implementation
static const String subscribe = 'subscribe';
Starts an operation, under an id the connection has not used yet.
static const String subscribe = 'subscribe';