data property
dynamic
data
final
The data of the response, null when the operation failed outright.
Implementation
final dynamic data;
The data of the response, null when the operation failed outright.
final dynamic data;