subprotocol constant
String
const subprotocol
The protocol token a WebSocket handshake negotiates for this protocol.
The server owning the socket is the one that reads
Sec-WebSocket-Protocol and decides which of the two servers in this
package to hand the connection to.
Implementation
static const String subprotocol = 'graphql-transport-ws';